==> credo-1.3.0.tar: lib/credo/cli/command/suggest/suggest_output.ex <==
defmodule Credo.CLI.Command.Suggest.SuggestOutput do
  @moduledoc false

  use Credo.CLI.Output.FormatDelegator,
    default: Credo.CLI.Command.Suggest.Output.Default,
    flycheck: Credo.CLI.Command.Suggest.Output.FlyCheck,
    oneline: Credo.CLI.Command.Suggest.Output.Oneline,
    json: Credo.CLI.Command.Suggest.Output.Json

  alias Credo.CLI.Output.UI

  def print_help(exec) do
    usage = ["Usage: ", :olive, "mix credo suggest [paths] [options]"]

    description = """

    Suggests objects from every category that Credo thinks can be improved.
    """

    example = [
      "Example: ",
      :olive,
      :faint,
      "$ mix credo suggest lib/**/*.ex --all -c names"
    ]

    options = """

    Arrows (↑ ↗ → ↘ ↓) hint at the importance of an issue.

    Suggest options:
      -a, --all                     Show all issues
      -A, --all-priorities          Show all issues including low priority ones
      -c, --checks                  Only include checks that match the given strings
          --config-file             Use the given config file
      -C, --config-name             Use the given config instead of "default"
          --enable-disabled-checks  Re-enable disabled checks that match the given strings
          --files-included          Only include these files (accepts globs, can be used multiple times)
          --files-excluded          Exclude these files (accepts globs, can be used multiple times)
          --format                  Display the list in a specific format (oneline,flycheck)
      -i, --ignore-checks           Ignore checks that match the given strings
          --min-priority            Minimum priority to show issues (high,medium,normal,low,lower or number)
          --mute-exit-status        Exit with status zero even if there are issues

    General options:
          --[no-]color        Toggle colored output
      -v, --version           Show version
      -h, --help              Show this help
    """

    UI.puts(usage)
    UI.puts(description)
    UI.puts(example)
    UI.puts(options)

    exec
  end
end

==> credo-1.4.0-rc.1.tar: lib/credo/cli/command/suggest/suggest_output.ex <==
defmodule Credo.CLI.Command.Suggest.SuggestOutput do
  @moduledoc false

  use Credo.CLI.Output.FormatDelegator,
    default: Credo.CLI.Command.Suggest.Output.Default,
    flycheck: Credo.CLI.Command.Suggest.Output.FlyCheck,
    oneline: Credo.CLI.Command.Suggest.Output.Oneline,
    json: Credo.CLI.Command.Suggest.Output.Json

  alias Credo.CLI.Output.UI

  def print_help(exec) do
    usage = ["Usage: ", :olive, "mix credo suggest [paths] [options]"]

    description = """

    Suggests objects from every category that Credo thinks can be improved.
    """

    example = [
      "Example: ",
      :olive,
      :faint,
      "$ mix credo suggest lib/**/*.ex --all -c names"
    ]

    options = """

    Arrows (↑ ↗ → ↘ ↓) hint at the importance of an issue.

    Suggest options:
      -a, --all                     Show all issues
      -A, --all-priorities          Show all issues including low priority ones
      -c, --checks                  Only include checks that match the given strings
          --checks-with-tag         Only include checks that match the given tag (can be used multiple times)
          --checks-without-tag      Ignore checks that match the given tag (can be used multiple times)
          --config-file             Use the given config file
      -C, --config-name             Use the given config instead of "default"
          --enable-disabled-checks  Re-enable disabled checks that match the given strings
          --files-included          Only include these files (accepts globs, can be used multiple times)
          --files-excluded          Exclude these files (accepts globs, can be used multiple times)
          --format                  Display the list in a specific format (json,flycheck,oneline)
      -i, --ignore-checks           Ignore checks that match the given strings
          --min-priority            Minimum priority to show issues (high,medium,normal,low,lower or number)
          --mute-exit-status        Exit with status zero even if there are issues

    General options:
          --[no-]color              Toggle colored output
      -v, --version                 Show version
      -h, --help                    Show this help
    """

    UI.puts(usage)
    UI.puts(description)
    UI.puts(example)
    UI.puts(options)

    exec
  end
end
